==> mgb-0.6.5.tar.gz: language/lang_dutch_utf8/lang_main.php <==
<?php
	
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// =========================== //
	// lang_main.php - Dutch 1.1.1 //
	// =========================== //
	//
	// This languagefile was translated by Gerard Vandeninden gerard@brookstruefriends.nl 
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// NEDERLANDSE strings of index.php
	$lang['install_directory_exists'] = "De installatiedirectory bestaat al.<br />Je deze het beste verwijderen!!<br>Maar vergeet niet <a href=\"install/upgrade.php\" title=\"Upgrade\">upgrade.php</a> te starten na een update!";
	$lang['new_entry'] = "Een bericht toevoegen";
	$lang['new_entry_descr'] = "Hier kan je een nieuw gasteboek bericht aanmaken";
	$lang['contact'] = "contact";
	$lang['contact_descr'] = "Hier kan je een bericht versturen naar de webmaster";
	$lang['adminpanel'] = "administratie";
	$lang['adminpanel_descr'] = "Ga naar Login";
	$lang['entry'] = "bericht";
	$lang['entries'] = "berichten";
	$lang['no_entries'] = "Er zijn op dit moment<br>geen berichten.";
	$lang['entries_on_pages'] = "berichten op {PAGES} Pagina`s";
	$lang['page_first'] = "First page";
	$lang['page_first_symbol'] = "&laquo;";
	$lang['page_forwards'] = "1 pagina vooruit";
	$lang['page_forwards_symbol'] = "&rsaquo;";
	$lang['page_last'] = "Last page";
	$lang['page_last_symbol'] = "&raquo;";
	$lang['page_backwards'] = "1 pagina terug";
	$lang['page_backwards_symbol'] = "&lsaquo;";
	$lang['anchor'] = "Ga rechtstreeks naar dit bericht";
	$lang['from'] = "uit";
	$lang['at'] = "om";
	$lang['oclock'] = "";
	$lang['comment'] = "commentaar";
	$lang['email_yes'] = "e-mail van {ENTRY_NAME}";
	$lang['email_no'] = "{ENTRY_NAME} krijgt geen mails van het gastenboek.";
	$lang['hp_of'] = "Homepage van {ENTRY_NAME}";
	$lang['gravatar'] = "Gravatar van {ENTRY_NAME}";

	// NEDERLANDSE strings of newentry.php
	$lang['name'] = "Uw Naam:";
	$lang['city'] = "Plaats:";
	$lang['email'] = "e-mail:";
	$lang['icq'] = "ICQ:";
	$lang['aim'] = "AIM:";
	$lang['msn'] = "MSN:";
	$lang['homepage'] = "Homepage:";
	$lang['message'] = "Uw bericht:";
	$lang['necessary_fields'] = "[ Verplichte velden zijn gemarkeerd met een ster (*) ]";
	$lang['user_notification'] = "Waarschuw per e-mail indien het bericht isgeactiveerd of wanneer er een comment is toegevoegd.";
	$lang['user_show_email'] = "Laat mijn e-mail adres zien in het gastenboek zodat andere gebruikers mij kunnen mailen. Als spam protectie is geactiveerd kan niemand je adres zien wel kunnen ze jou mailen door middel van een e-mail formulier.";
	$lang['send'] = "Verzenden";
	$lang['preview'] = "Preview";
	$lang['errormessage1'] = "Vul een bericht in a.u.b.!";
	$lang['errormessage2'] = "Vul een geldig e-mail adres in a.u.b.!";
	$lang['errormessage3'] = "Vul uw naam in a.u.b.!";
	$lang['errormessage4'] = "is geen geldig<br>e-mail adres!";
	$lang['errormessage5'] = "is geen geldig<br>ICQ nummer!";
	$lang['errormessage6'] = "De IP-blokkade verbiedt een volgende entry!";
	$lang['errormessage7'] = "De captcha-code was niet goed ingetypt!";
	$lang['errormessage8'] = "Deze gebruiker ontvangt geen e-mail";
	$lang['errormessage9'] = "Er was een fout bij het versturen van de mail!";
	$lang['security_code'] = "Beveiligings-code (captcha)";	
	$lang['captcha_what_is_that'] = "Wat is dit?";
	$lang['captcha_wikipedia'] = "http://en.wikipedia.org/wiki/Captcha";
	$lang['captcha_tooltip'] = "Een nieuwe gastenboek entry vereist het invoeren van de captcha-code, dit om geautomatiseerd invoeren te voorkomen. Typ enkel HOOFDLETTERS. Als de code onleesbaar is, laat dan het veld leeg en klik op ''Verzenden''. Er zal een nieuwe captcha gegenereerd worden. Je andere velden blijven dan ingevuld. Als er geen nieuwe captcha gegenereerd wordt klik dan op ''vernieuwen'' of typ [CTRL]+[R].";
	$lang['back_to_mainpage'] = "Terug naar de hoofdpagina";
	$lang['back'] = "Terug";
	$lang['entry_success_mod'] = "Je bericht is opgeslagen.<br>Het wordt door de admin geevalueerd en dan geactiveerd.";
	$lang['entry_success'] = "Je bericht is opgeslagen. Je kan het nu bekijken.";
	$lang['forwarding'] = "Je wordt automatisch doorgeschakeld in 5 seconden. Anders klik op ''Terug naar de hoofdpagina''.";
	$lang['bbcodes'] = "BBCodes:";
	$lang['bbcode_help_bold'] = "vet";
	$lang['bbcode_help_italic'] = "cursief";
	$lang['bbcode_help_url'] = "website invoegen";
	$lang['bbcode_textsize'] = "tekst grootte";
	$lang['bbcode_extrasmall'] = "extraklein";
	$lang['bbcode_small'] = "klein";
	$lang['bbcode_default'] = "standaard";
	$lang['bbcode_big'] = "groot";
	$lang['bbcode_extrabig'] = "extra groot";
	$lang['bbcode_textcolor'] = "tekst kleur";
	$lang['bbcode_help_size'] = "tekst grootte";
	$lang['smileys'] = "smileys:";
	$lang['sendmail_admin_title'] = "Nieuwe gastenboek vermelding van '{NAME}'"; 
	$lang['sendmail_user_title'] = "Jouw gastenboek vermelding bij {DOMAIN}";

	// NEDERLANDSE strings of email.php
	$lang['email_name'] = "Uw naam:";
	$lang['email_email'] = "Uw e-mail:";
	$lang['email_message'] = "Uw bericht:";
	$lang['email_sent_to'] = "Dit bericht wordt verzonden naar:";
	$lang['email_send'] = "Verstuur";
	$lang['email_caption'] = "E-mail van '{NAME}' over het gastenboek van {DOMAIN}";
	$lang['email_sender'] = "Afzender:";
	$lang['email_receiver'] = "Ontvanger:";
	$lang['email_from'] = "Van:";
	$lang['email_sendcopytome'] = "Ik wil graag een copie naar mijn adres.";
	$lang['email_success'] = "Uw e-mail is succesvol verzonden.";
	$lang['email_fail'] = "De e-mail kon niet verzonden worden. Er is misschien een probleem met de mailserver.";
?>

==> mgb-0.6.7.tar.gz: language/lang_dutch_utf8/lang_main.php <==
<?php
	
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// =========================== //
	// lang_main.php - Dutch 1.1.2 //
	// =========================== //
	//
	// This languagefile was translated by Gerard Vandeninden gerard@brookstruefriends.nl 
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// NEDERLANDSE strings of index.php
	$lang['install_directory_exists'] = "De installatiedirectory bestaat al.<br />Je deze het beste verwijderen!!<br>Maar vergeet niet <a href=\"install/upgrade.php\" title=\"Upgrade\">upgrade.php</a> te starten na een update!";
	$lang['new_entry'] = "Een bericht toevoegen";
	$lang['new_entry_descr'] = "Hier kan je een nieuw gasteboek bericht aanmaken";
	$lang['contact'] = "contact";
	$lang['contact_descr'] = "Hier kan je een bericht versturen naar de webmaster";
	$lang['adminpanel'] = "administratie";
	$lang['adminpanel_descr'] = "Ga naar Login";
	$lang['entry'] = "bericht";
	$lang['entries'] = "berichten";
	$lang['no_entries'] = "Er zijn op dit moment<br>geen berichten.";
	$lang['entries_on_pages'] = "berichten op {PAGES} Pagina`s";
	$lang['page_first'] = "Eerste pagina";
	$lang['page_first_symbol'] = "&laquo;";
	$lang['page_forwards'] = "1 pagina vooruit";
	$lang['page_forwards_symbol'] = "&rsaquo;";
	$lang['page_last'] = "Laatste pagina";
	$lang['page_last_symbol'] = "&raquo;";
	$lang['page_backwards'] = "1 pagina terug";
	$lang['page_backwards_symbol'] = "&lsaquo;";
	$lang['anchor'] = "Ga rechtstreeks naar dit bericht";
	$lang['from'] = "uit";
	$lang['at'] = "om";
	$lang['oclock'] = "";
	$lang['comment'] = "commentaar";
	$lang['email_yes'] = "e-mail van {ENTRY_NAME}";
	$lang['email_no'] = "{ENTRY_NAME} krijgt geen mails van het gastenboek.";
	$lang['hp_of'] = "Homepage van {ENTRY_NAME}";
	$lang['gravatar'] = "Gravatar van {ENTRY_NAME}";

	// NEDERLANDSE strings of newentry.php
	$lang['name'] = "Uw Naam:";
	$lang['city'] = "Plaats:";
	$lang['email'] = "e-mail:";
	$lang['icq'] = "ICQ:";
	$lang['aim'] = "AIM:";
	$lang['msn'] = "MSN:";
	$lang['homepage'] = "Homepage:";
	$lang['message'] = "Uw bericht:";
	$lang['necessary_fields'] = "[ Verplichte velden zijn gemarkeerd met een ster (*) ]";
	$lang['user_notification'] = "Waarschuw per e-mail indien het bericht isgeactiveerd of wanneer er een comment is toegevoegd.";
	$lang['user_show_email'] = "Laat mijn e-mail adres zien in het gastenboek zodat andere gebruikers mij kunnen mailen. Als spam protectie is geactiveerd kan niemand je adres zien wel kunnen ze jou mailen door middel van een e-mail formulier.";
	$lang['send'] = "Verzenden";
	$lang['preview'] = "Preview";
	$lang['errormessage1'] = "Vul een bericht in a.u.b.!";
	$lang['errormessage2'] = "Vul een geldig e-mail adres in a.u.b.!";
	$lang['errormessage3'] = "Vul uw naam in a.u.b.!";
	$lang['errormessage4'] = "is geen geldig<br>e-mail adres!";
	$lang['errormessage5'] = "is geen geldig<br>ICQ nummer!";
	$lang['errormessage6'] = "De IP-blokkade verbiedt een volgende entry!";
	$lang['errormessage7'] = "De captcha-code was niet goed ingetypt!";
	$lang['errormessage8'] = "Deze gebruiker ontvangt geen e-mail";
	$lang['errormessage9'] = "Er was een fout bij het versturen van de mail!";
	$lang['security_code'] = "Beveiligings-code (captcha)";	
	$lang['captcha_what_is_that'] = "Wat is dit?";
	$lang['captcha_wikipedia'] = "http://en.wikipedia.org/wiki/Captcha";
	$lang['captcha_tooltip'] = "Een nieuwe gastenboek entry vereist het invoeren van de captcha-code, dit om geautomatiseerd invoeren te voorkomen. Typ enkel HOOFDLETTERS. Als de code onleesbaar is, laat dan het veld leeg en klik op ''Verzenden''. Er zal een nieuwe captcha gegenereerd worden. Je andere velden blijven dan ingevuld. Als er geen nieuwe captcha gegenereerd wordt klik dan op ''vernieuwen'' of typ [CTRL]+[R].";
	$lang['back_to_mainpage'] = "Terug naar de hoofdpagina";
	$lang['back'] = "Terug";
	$lang['entry_success_mod'] = "Je bericht is opgeslagen.<br>Het wordt door de admin geevalueerd en dan geactiveerd.";
	$lang['entry_success'] = "Je bericht is opgeslagen. Je kan het nu bekijken.";
	$lang['forwarding'] = "Je wordt automatisch doorgeschakeld in 5 seconden. Anders klik op ''Terug naar de hoofdpagina''.";
	$lang['bbcodes'] = "BBCodes:";
	$lang['bbcode_help_bold'] = "vet";
	$lang['bbcode_help_italic'] = "cursief";
	$lang['bbcode_help_url'] = "website invoegen";
	$lang['bbcode_textsize'] = "tekst grootte";
	$lang['bbcode_extrasmall'] = "extraklein";
	$lang['bbcode_small'] = "klein";
	$lang['bbcode_default'] = "standaard";
	$lang['bbcode_big'] = "groot";
	$lang['bbcode_extrabig'] = "extra groot";
	$lang['bbcode_textcolor'] = "tekst kleur";
	$lang['bbcode_help_size'] = "tekst grootte";
	$lang['smileys'] = "smileys:";
	$lang['sendmail_admin_title'] = "Nieuwe gastenboek vermelding van '{NAME}'"; 
	$lang['sendmail_user_title'] = "Jouw gastenboek vermelding bij {DOMAIN}";

	// NEDERLANDSE strings of email.php
	$lang['email_name'] = "Uw naam:";
	$lang['email_email'] = "Uw e-mail:";
	$lang['email_message'] = "Uw bericht:";
	$lang['email_sent_to'] = "Dit bericht wordt verzonden naar:";
	$lang['email_send'] = "Verzenden";
	$lang['email_caption'] = "E-mail van '{NAME}' over het gastenboek van {DOMAIN}";
	$lang['email_sender'] = "Afzender:";
	$lang['email_receiver'] = "Ontvanger:";
	$lang['email_from'] = "Van:";
	$lang['email_sendcopytome'] = "Ik wil graag een copie naar mijn adres.";
	$lang['email_success'] = "Uw e-mail is succesvol verzonden.";
	$lang['email_fail'] = "De e-mail kon niet verzonden worden. Er is misschien een probleem met de mailserver.";
?>
